@@ -5,7 +5,7 @@
 ;; Filename: ido-completing-read+.el
 ;; Author: Ryan Thompson
 ;; Created: Sat Apr  4 13:41:20 2015 (-0700)
-;; Version: 4.11
+;; Version: 4.12
 ;; Package-Requires: ((emacs "24.4") (cl-lib "0.5") (s "0.1") (memoize "1.1"))
 ;; URL: https://github.com/DarwinAwardWinner/ido-completing-read-plus
 ;; Keywords: ido, completion, convenience
@@ -77,7 +77,7 @@
 ;;
 ;;; Code:
 
-(defconst ido-completing-read+-version "4.11"
+(defconst ido-completing-read+-version "4.12"
   "Currently running version of ido-completing-read+.
 
 Note that when you update ido-completing-read+, this variable may
@@ -296,7 +296,11 @@ disable fallback based on collection size, set this to nil."
     ;; https://github.com/DarwinAwardWinner/ido-completing-read-plus/issues/44
     tmm-prompt
     ;; https://github.com/DarwinAwardWinner/ido-completing-read-plus/issues/156
-    org-tags-completion-function)
+    org-tags-completion-function
+    ;; https://github.com/DarwinAwardWinner/ido-completing-read-plus/issues/159
+    ffap-read-file-or-url
+    ffap-read-file-or-url-internal
+    )
   "Functions & commands for which ido-cr+ should be disabled.
 
 Each entry can be either a symbol or a string. A symbol means to
